@@ -33,7 +33,6 @@
 #include "createdialog.h"
 #include "jobs.h"
 
-#include <KConfig>
 #include <KJobTrackerInterface>
 #include <KIO/JobTracker>
 #include <KLocalizedString>
@@ -182,7 +181,7 @@ void AddToArchive::slotStartJob()
 
         const QDir stripDir(m_firstPath);
 
-        foreach (Archive::Entry *entry, m_entries) {
+        for (Archive::Entry *entry : qAsConst(m_entries)) {
             entry->setFullPath(stripDir.absoluteFilePath(entry->fullPath()));
         }
 
