@@ -36,9 +36,7 @@
 
 #include <KMessageBox>
 #include <KSharedConfig>
-#include <KUrlRequester>
 
-#include <QDebug>
 #include <QMimeDatabase>
 #include <QUrl>
 
@@ -79,7 +77,7 @@ CreateDialog::CreateDialog(QWidget *parent,
     }
 
     // Populate combobox with mimetypes.
-    foreach (const QString &type, m_supportedMimeTypes) {
+    for (const QString &type : qAsConst(m_supportedMimeTypes)) {
         m_ui->mimeComboBox->addItem(QMimeDatabase().mimeTypeForName(type).comment());
     }
 
@@ -87,9 +85,13 @@ CreateDialog::CreateDialog(QWidget *parent,
     connect(m_ui->buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(m_ui->buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(this, &QDialog::accepted, this, &CreateDialog::slotUpdateDefaultMimeType);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_ui->mimeComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CreateDialog::slotUpdateWidgets);
     connect(m_ui->mimeComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CreateDialog::slotUpdateFilenameExtension);
-
+#else
+    connect(m_ui->mimeComboBox, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &CreateDialog::slotUpdateWidgets);
+    connect(m_ui->mimeComboBox, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &CreateDialog::slotUpdateFilenameExtension);
+#endif
     m_vlayout->addWidget(m_ui);
 
     m_ui->optionsWidget->setMimeType(currentMimeType());
